@@ -78,13 +78,15 @@ class BatchQuery(object):
     """
     _consistency = None
 
-    def __init__(self, batch_type=None, timestamp=None, consistency=None):
+
+    def __init__(self, batch_type=None, timestamp=None, consistency=None, execute_on_exception=False):
         self.queries = []
         self.batch_type = batch_type
         if timestamp is not None and not isinstance(timestamp, datetime):
             raise CQLEngineException('timestamp object must be an instance of datetime')
         self.timestamp = timestamp
         self._consistency = consistency
+        self._execute_on_exception = execute_on_exception
 
     def add_query(self, query):
         if not isinstance(query, BaseCQLStatement):
@@ -125,8 +127,8 @@ class BatchQuery(object):
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
-        #don't execute if there was an exception
-        if exc_type is not None: return
+        #don't execute if there was an exception by default
+        if exc_type is not None and not self._execute_on_exception: return
         self.execute()
 
 
@@ -318,6 +320,11 @@ class AbstractQuerySet(object):
     def all(self):
         return copy.deepcopy(self)
 
+    def consistency(self, consistency):
+        clone = copy.deepcopy(self)
+        clone._consistency = consistency
+        return clone
+
     def _parse_filter_arg(self, arg):
         """
         Parses a filter arg in the format:
@@ -355,11 +362,23 @@ class AbstractQuerySet(object):
                 column = self.model._get_column(col_name)
             except KeyError:
                 if col_name == 'pk__token':
+                    if not isinstance(val, Token):
+                        raise QueryException("Virtual column 'pk__token' may only be compared to Token() values")
                     column = columns._PartitionKeysToken(self.model)
                     quote_field = False
                 else:
                     raise QueryException("Can't resolve column name: '{}'".format(col_name))
 
+            if isinstance(val, Token):
+                if col_name != 'pk__token':
+                    raise QueryException("Token() values may only be compared to the 'pk__token' virtual column")
+                partition_columns = column.partition_columns
+                if len(partition_columns) != len(val.value):
+                    raise QueryException(
+                        'Token() received {} arguments but model has {} partition keys'.format(
+                            len(partition_columns), len(val.value)))
+                val.set_columns(partition_columns)
+
             #get query operator, or use equals if not supplied
             operator_class = BaseWhereOperator.get_operator(col_op or 'EQ')
             operator = operator_class()
@@ -551,17 +570,15 @@ class ModelQuerySet(AbstractQuerySet):
         """ Checks that a filterset will not create invalid select statement """
         #check that there's either a = or IN relationship with a primary key or indexed field
         equal_ops = [self.model._columns.get(w.field) for w in self._where if isinstance(w.operator, EqualsOperator)]
-        token_ops = [self.model._columns.get(w.field) for w in self._where if isinstance(w.operator, Token)]
-        if not any([w.primary_key or w.index for w in equal_ops]) and not token_ops:
+        token_comparison = any([w for w in self._where if isinstance(w.value, Token)])
+        if not any([w.primary_key or w.index for w in equal_ops]) and not token_comparison:
             raise QueryException('Where clauses require either a "=" or "IN" comparison with either a primary key or indexed field')
 
         if not self._allow_filtering:
             #if the query is not on an indexed field
             if not any([w.index for w in equal_ops]):
-                if not any([w.partition_key for w in equal_ops]) and not token_ops:
+                if not any([w.partition_key for w in equal_ops]) and not token_comparison:
                     raise QueryException('Filtering on a clustering key without a partition key is not allowed unless allow_filtering() is called on the querset')
-            if any(not w.partition_key for w in token_ops):
-                raise QueryException('The token() function is only supported on the partition key')
 
     def _select_fields(self):
         if self._defer_fields or self._only_fields:
@@ -616,11 +633,6 @@ class ModelQuerySet(AbstractQuerySet):
         clone._flat_values_list = flat
         return clone
 
-    def consistency(self, consistency):
-        clone = copy.deepcopy(self)
-        clone._consistency = consistency
-        return clone
-
     def ttl(self, ttl):
         clone = copy.deepcopy(self)
         clone._ttl = ttl
