@@ -218,7 +218,7 @@ class ListUpdateClause(ContainerUpdateClause):
         if not self._analyzed: self._analyze()
         qs = []
         ctx_id = self.context_id
-        if self._assignments:
+        if self._assignments is not None:
             qs += ['"{}" = :{}'.format(self.field, ctx_id)]
             ctx_id += 1
 
@@ -233,12 +233,12 @@ class ListUpdateClause(ContainerUpdateClause):
 
     def get_context_size(self):
         if not self._analyzed: self._analyze()
-        return int(bool(self._assignments)) + int(bool(self._append)) + int(bool(self._prepend))
+        return int(self._assignments is not None) + int(bool(self._append)) + int(bool(self._prepend))
 
     def update_context(self, ctx):
         if not self._analyzed: self._analyze()
         ctx_id = self.context_id
-        if self._assignments:
+        if self._assignments is not None:
             ctx[str(ctx_id)] = self._to_database(self._assignments)
             ctx_id += 1
         if self._prepend:
@@ -263,6 +263,7 @@ class ListUpdateClause(ContainerUpdateClause):
             # rewrite the whole list
             self._assignments = self.value
 
+
         elif len(self.previous) == 0:
             # if we're updating from an empty
             # list, do a complete insert
@@ -582,15 +583,16 @@ class UpdateStatement(AssignmentStatement):
 
     def __unicode__(self):
         qs = ['UPDATE', self.table]
+
+        if self.ttl:
+            qs += ["USING TTL {}".format(self.ttl)]
+
         qs += ['SET']
         qs += [', '.join([unicode(c) for c in self.assignments])]
 
         if self.where_clauses:
             qs += [self._where]
 
-        if self.ttl:
-            qs += ["USING TTL {}".format(self.ttl)]
-
         return ' '.join(qs)
 
 
